@@ -1,5 +1,5 @@
 # #
-# Copyright 2013-2022 Ghent University
+# Copyright 2013-2023 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -27,7 +27,9 @@ This describes the easyconfig parser
 
 The parser is format version aware
 
-:author: Stijn De Weirdt (Ghent University)
+Authors:
+
+* Stijn De Weirdt (Ghent University)
 """
 import os
 import re
