@@ -28,13 +28,14 @@
 """
 Support for PGI compilers (pgcc, pgc++, pgf90/pgfortran) as toolchain compilers.
 
-:author: Bart Oldeman (McGill University, Calcul Quebec, Compute Canada)
-:author: Damian Alvarez (Forschungszentrum Juelich GmbH)
+Authors:
+
+* Bart Oldeman (McGill University, Calcul Quebec, Compute Canada)
+* Damian Alvarez (Forschungszentrum Juelich GmbH)
 """
 
-from distutils.version import LooseVersion
-
 import easybuild.tools.systemtools as systemtools
+from easybuild.tools import LooseVersion
 from easybuild.tools.toolchain.compiler import Compiler
 
 
