@@ -1,5 +1,5 @@
 ##
-# Copyright 2012-2022 Ghent University
+# Copyright 2012-2023 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -25,12 +25,14 @@
 """
 Support for Intel FFTW as toolchain FFT library.
 
-:author: Stijn De Weirdt (Ghent University)
-:author: Kenneth Hoste (Ghent University)
+Authors:
+
+* Stijn De Weirdt (Ghent University)
+* Kenneth Hoste (Ghent University)
 """
 import os
-from distutils.version import LooseVersion
 
+from easybuild.tools import LooseVersion
 from easybuild.tools.build_log import EasyBuildError, dry_run_warning
 from easybuild.tools.config import build_option
 from easybuild.toolchains.fft.fftw import Fftw
