@@ -1,5 +1,5 @@
 ##
-# Copyright 2013-2022 Ghent University
+# Copyright 2013-2023 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -25,22 +25,24 @@
 """
 EasyBuild support for foss compiler toolchain (includes GCC, OpenMPI, OpenBLAS, LAPACK, ScaLAPACK and FFTW).
 
-:author: Kenneth Hoste (Ghent University)
-"""
-from distutils.version import LooseVersion
+Authors:
 
+* Kenneth Hoste (Ghent University)
+"""
 from easybuild.toolchains.gompi import Gompi
+from easybuild.toolchains.gfbf import Gfbf
 from easybuild.toolchains.golf import Golf
 from easybuild.toolchains.fft.fftw import Fftw
 from easybuild.toolchains.linalg.flexiblas import FlexiBLAS
 from easybuild.toolchains.linalg.openblas import OpenBLAS
 from easybuild.toolchains.linalg.scalapack import ScaLAPACK
+from easybuild.tools import LooseVersion
 
 
 class Foss(Gompi, OpenBLAS, FlexiBLAS, ScaLAPACK, Fftw):
     """Compiler toolchain with GCC, OpenMPI, OpenBLAS, ScaLAPACK and FFTW."""
     NAME = 'foss'
-    SUBTOOLCHAIN = [Gompi.NAME, Golf.NAME]
+    SUBTOOLCHAIN = [Gompi.NAME, Golf.NAME, Gfbf.NAME]
 
     def __init__(self, *args, **kwargs):
         """Toolchain constructor."""
