@@ -1,5 +1,5 @@
 ##
-# Copyright 2012-2022 Ghent University
+# Copyright 2012-2023 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -25,9 +25,11 @@
 """
 EasyBuild support for gimpic compiler toolchain (includes GCC and IntelMPI and CUDA).
 
-:author: Kenneth Hoste (Ghent University)
-:author: Fotis Georgatos (Uni.Lu, NTUA)
-:author: Ake Sandgren (HPC2N, Umea University)
+Authors:
+
+* Kenneth Hoste (Ghent University)
+* Fotis Georgatos (Uni.Lu, NTUA)
+* Ake Sandgren (HPC2N, Umea University)
 """
 
 from easybuild.toolchains.gcccuda import GccCUDA
