@@ -1,5 +1,5 @@
 ##
-# Copyright 2013-2022 Ghent University
+# Copyright 2013-2023 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -25,7 +25,9 @@
 """
 EasyBuild support for iibff compiler toolchain (includes Intel compilers + MPI, BLIS, libFLAME, ScaLAPACK and FFTW).
 
-:author: Kenneth Hoste (HPC-UGent)
+Authors:
+
+* Kenneth Hoste (HPC-UGent)
 """
 
 from easybuild.toolchains.iimpi import Iimpi
