@@ -5,7 +5,9 @@
 """
 EasyBuild support for xlmpich compiler toolchain (includes IBM XL compilers (xlc, xlf) and MPICH).
 
-:author: Jack Perdue <j-perdue@tamu.edu> - TAMU HPRC - http://sc.tamu.edu
+Authors:
+
+* Jack Perdue <j-perdue@tamu.edu> - TAMU HPRC - http://sc.tamu.edu
 """
 from easybuild.toolchains.compiler.ibmxl import IBMXL
 from easybuild.toolchains.mpi.mvapich2 import Mvapich2
