@@ -36,4 +36,15 @@ Authors:
 """
 __path__ = __import__('pkgutil').extend_path(__path__, __name__)
 
+
+import distutils.version
+import warnings
 from easybuild.tools.loose_version import LooseVersion  # noqa(F401)
+
+
+class StrictVersion(distutils.version.StrictVersion):
+    """Temporary wrapper over distuitls StrictVersion that silences the deprecation warning"""
+    def __init__(self, *args, **kwargs):
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore", category=DeprecationWarning)
+            distutils.version.StrictVersion.__init__(self, *args, **kwargs)
