@@ -2034,8 +2034,8 @@ class ConfigObj(Section):
 
         # Turn the list to a string, joined with correct newlines
         newline = self.newlines or os.linesep
-        if (getattr(outfile, 'mode', None) is not None and outfile.mode == 'w'
-                and sys.platform == 'win32' and newline == '\r\n'):
+        if (getattr(outfile, 'mode', None) is not None and outfile.mode == 'w' and
+                sys.platform == 'win32' and newline == '\r\n'):
             # Windows specific hack to avoid writing '\r\r\n'
             newline = '\n'
         output = self._a_to_u(newline).join(out)
