@@ -49,7 +49,7 @@ from easybuild.tools.config import build_option, get_module_syntax, install_path
 from easybuild.tools.filetools import convert_name, mkdir, read_file, remove_file, resolve_path, symlink, write_file
 from easybuild.tools.modules import ROOT_ENV_VAR_NAME_PREFIX, EnvironmentModulesC, Lmod, modules_tool
 from easybuild.tools.py2vs3 import string_type
-from easybuild.tools.utilities import get_subclasses, quote_str
+from easybuild.tools.utilities import get_subclasses, nub, quote_str
 
 
 _log = fancylogger.getLogger('module_generator', fname=False)
@@ -502,6 +502,12 @@ class ModuleGenerator(object):
         """
         raise NotImplementedError
 
+    def msg_on_unload(self, msg):
+        """
+        Add a message that should be printed when unloading the module.
+        """
+        raise NotImplementedError
+
     def set_alias(self, key, value):
         """
         Generate set-alias statement in modulefile for the given key/value pair.
@@ -606,28 +612,18 @@ class ModuleGenerator(object):
 
     def _generate_extension_list(self):
         """
-        Generate a string with a comma-separated list of extensions.
-        """
-        # We need only name and version, so don't resolve templates
-        exts_list = self.app.cfg.get_ref('exts_list')
-        extensions = ', '.join(sorted(['-'.join(ext[:2]) for ext in exts_list], key=str.lower))
+        Generate a string with a list of extensions.
 
-        return extensions
+        The name and version are separated by name_version_sep and each extension is separated by ext_sep
+        """
+        return self.app.make_extension_string()
 
     def _generate_extensions_list(self):
         """
         Generate a list of all extensions in name/version format
         """
-        exts_list = self.app.cfg['exts_list']
-        # the format is extension_name/extension_version
-        exts_ver_list = []
-        for ext in exts_list:
-            if isinstance(ext, tuple):
-                exts_ver_list.append('%s/%s' % (ext[0], ext[1]))
-            elif isinstance(ext, string_type):
-                exts_ver_list.append(ext)
-
-        return sorted(exts_ver_list, key=str.lower)
+        exts_str = self.app.make_extension_string(name_version_sep='/', ext_sep=',')
+        return exts_str.split(',') if exts_str else []
 
     def _generate_help_text(self):
         """
@@ -671,7 +667,7 @@ class ModuleGenerator(object):
         if multi_deps:
             compatible_modules_txt = '\n'.join([
                 "This module is compatible with the following modules, one of each line is required:",
-            ] + ['* %s' % d for d in multi_deps])
+            ] + ['* %s' % d for d in nub(multi_deps)])
             lines.extend(self._generate_section("Compatible modules", compatible_modules_txt))
 
         # Extensions (if any)
@@ -951,6 +947,15 @@ class ModuleGeneratorTcl(ModuleGenerator):
         print_cmd = "puts stderr %s" % quote_str(msg, tcl=True)
         return '\n'.join(['', self.conditional_statement("module-info mode load", print_cmd, indent=False)])
 
+    def msg_on_unload(self, msg):
+        """
+        Add a message that should be printed when unloading the module.
+        """
+        # escape any (non-escaped) characters with special meaning by prefixing them with a backslash
+        msg = re.sub(r'((?<!\\)[%s])' % ''.join(self.CHARS_TO_ESCAPE), r'\\\1', msg)
+        print_cmd = "puts stderr %s" % quote_str(msg, tcl=True)
+        return '\n'.join(['', self.conditional_statement("module-info mode unload", print_cmd, indent=False)])
+
     def update_paths(self, key, paths, prepend=True, allow_abs=False, expand_relpaths=True):
         """
         Generate prepend-path or append-path statements for the given list of paths.
@@ -1384,6 +1389,14 @@ class ModuleGeneratorLua(ModuleGenerator):
         stmt = 'io.stderr:write(%s%s%s)' % (self.START_STR, self.check_str(msg), self.END_STR)
         return '\n' + self.conditional_statement('mode() == "load"', stmt, indent=False)
 
+    def msg_on_unload(self, msg):
+        """
+        Add a message that should be printed when loading the module.
+        """
+        # take into account possible newlines in messages by using [==...==] (requires Lmod 5.8)
+        stmt = 'io.stderr:write(%s%s%s)' % (self.START_STR, self.check_str(msg), self.END_STR)
+        return '\n' + self.conditional_statement('mode() == "unload"', stmt, indent=False)
+
     def modulerc(self, module_version=None, filepath=None, modulerc_txt=None):
         """
         Generate contents of .modulerc(.lua) file, in Lua syntax (but only if Lmod is recent enough, i.e. >= 7.7.38)
