@@ -1,5 +1,5 @@
 ##
-# Copyright 2011-2022 Ghent University
+# Copyright 2011-2023 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -25,7 +25,9 @@
 """
 Declares easybuild.tools.module_naming_scheme namespace, in an extendable way.
 
-:author: Jens Timmerman (Ghent University)
-:author: Kenneth Hoste (Ghent University)
+Authors:
+
+* Jens Timmerman (Ghent University)
+* Kenneth Hoste (Ghent University)
 """
 __path__ = __import__('pkgutil').extend_path(__path__, __name__)
