@@ -1,5 +1,5 @@
 ##
-# Copyright 2011-2022 Ghent University
+# Copyright 2011-2023 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -25,8 +25,10 @@
 """
 Module naming scheme API.
 
-:author: Jens Timmerman (Ghent University)
-:author: Kenneth Hoste (Ghent University)
+Authors:
+
+* Jens Timmerman (Ghent University)
+* Kenneth Hoste (Ghent University)
 """
 import re
 
