@@ -40,9 +40,9 @@ Authors:
 import os
 import re
 import shlex
-from distutils.version import StrictVersion
 
 from easybuild.base import fancylogger
+from easybuild.tools import StrictVersion
 from easybuild.tools.build_log import EasyBuildError, print_warning
 from easybuild.tools.config import ERROR, IGNORE, PURGE, UNLOAD, UNSET
 from easybuild.tools.config import EBROOT_ENV_VAR_ACTIONS, LOADED_MODULES_ACTIONS
@@ -274,9 +274,7 @@ class ModulesTool(object):
                     depr_msg = "Support for %s version < %s is deprecated, " % (self.NAME, self.DEPR_VERSION)
                     depr_msg += "found version %s" % self.version
 
-                    silence_deprecation_warnings = build_option('silence_deprecation_warnings') or []
-
-                    if self.version.startswith('6') and 'Lmod6' in silence_deprecation_warnings:
+                    if self.version.startswith('6') and 'Lmod6' in build_option('silence_deprecation_warnings'):
                         self.log.warning(depr_msg)
                     else:
                         self.log.deprecated(depr_msg, '5.0')
@@ -1330,6 +1328,54 @@ class EnvironmentModules(EnvironmentModulesTcl):
     MAX_VERSION = None
     VERSION_REGEXP = r'^Modules\s+Release\s+(?P<version>\d\S*)\s'
 
+    def __init__(self, *args, **kwargs):
+        """Constructor, set Environment Modules-specific class variable values."""
+        # ensure in-depth modulepath search (MODULES_AVAIL_INDEPTH has been introduced in v4.3)
+        setvar('MODULES_AVAIL_INDEPTH', '1', verbose=False)
+        # match against module name start (MODULES_SEARCH_MATCH has been introduced in v4.3)
+        setvar('MODULES_SEARCH_MATCH', 'starts_with', verbose=False)
+        # ensure no debug message (MODULES_VERBOSITY has been introduced in v4.3)
+        setvar('MODULES_VERBOSITY', 'normal', verbose=False)
+        # make module search case sensitive (search is case insensitive by default since v5.0)
+        setvar('MODULES_ICASE', 'never', verbose=False)
+        # disable extended default (introduced in v4.4 and enabled by default in v5.0)
+        setvar('MODULES_EXTENDED_DEFAULT', '0', verbose=False)
+        # hard disable output redirection, output messages are expected on stderr
+        setvar('MODULES_REDIRECT_OUTPUT', '0', verbose=False)
+        # make sure modulefile cache is ignored (cache mechanism supported since v5.3)
+        setvar('MODULES_IGNORE_CACHE', '1', verbose=False)
+        # ensure only module names are returned on avail (MODULES_AVAIL_TERSE_OUTPUT added in v4.7)
+        setvar('MODULES_AVAIL_TERSE_OUTPUT', '', verbose=False)
+        # ensure only module names are returned on list (MODULES_LIST_TERSE_OUTPUT added in v4.7)
+        setvar('MODULES_LIST_TERSE_OUTPUT', '', verbose=False)
+
+        super(EnvironmentModules, self).__init__(*args, **kwargs)
+
+    def check_module_function(self, allow_mismatch=False, regex=None):
+        """Check whether selected module tool matches 'module' function definition."""
+        # Modules 5.1.0+: module command is called from _module_raw shell function
+        # Modules 4.2.0..5.0.1: module command is called from _module_raw shell function if it has
+        #   been initialized in an interactive shell session (i.e., a session attached to a tty)
+        if self.testing:
+            if '_module_raw' in os.environ:
+                out, ec = os.environ['_module_raw'], 0
+            else:
+                out, ec = None, 1
+        else:
+            cmd = "type _module_raw"
+            out, ec = run_cmd(cmd, simple=False, log_ok=False, log_all=False, force_in_dry_run=True, trace=False)
+
+        if regex is None:
+            regex = r".*%s" % os.path.basename(self.cmd)
+        mod_cmd_re = re.compile(regex, re.M)
+
+        if ec == 0 and mod_cmd_re.search(out):
+            self.log.debug("Found pattern '%s' in defined '_module_raw' function." % mod_cmd_re.pattern)
+        else:
+            self.log.debug("Pattern '%s' not found in '_module_raw' function, falling back to 'module' function",
+                           mod_cmd_re.pattern)
+            super(EnvironmentModules, self).check_module_function(allow_mismatch, regex)
+
     def check_module_output(self, cmd, stdout, stderr):
         """Check output of 'module' command, see if if is potentially invalid."""
         if "_mlstatus = False" in stdout:
@@ -1337,6 +1383,27 @@ class EnvironmentModules(EnvironmentModulesTcl):
         else:
             self.log.debug("No errors detected when running module command '%s'", cmd)
 
+    def get_setenv_value_from_modulefile(self, mod_name, var_name):
+        """
+        Get value for specific 'setenv' statement from module file for the specified module.
+
+        :param mod_name: module name
+        :param var_name: name of the variable being set for which value should be returned
+        """
+        # Tcl-based module tools produce "module show" output with setenv statements like:
+        # "setenv		 GCC_PATH /opt/gcc/8.3.0"
+        # "setenv		 VAR {some text}
+        # - line starts with 'setenv'
+        # - whitespace (spaces & tabs) around variable name
+        # - curly braces around value if it contain spaces
+        value = super(EnvironmentModules, self).get_setenv_value_from_modulefile(mod_name=mod_name,
+                                                                                 var_name=var_name)
+
+        if value:
+            value = value.strip('{}')
+
+        return value
+
 
 class Lmod(ModulesTool):
     """Interface to Lmod."""
@@ -1347,7 +1414,6 @@ class Lmod(ModulesTool):
     DEPR_VERSION = '7.0.0'
     REQ_VERSION_DEPENDS_ON = '7.6.1'
     VERSION_REGEXP = r"^Modules\s+based\s+on\s+Lua:\s+Version\s+(?P<version>\d\S*)\s"
-    USER_CACHE_DIR = os.path.join(os.path.expanduser('~'), '.lmod.d', '.cache')
 
     SHOW_HIDDEN_OPTION = '--show-hidden'
 
@@ -1363,7 +1429,14 @@ class Lmod(ModulesTool):
         setvar('LMOD_EXTENDED_DEFAULT', 'no', verbose=False)
 
         super(Lmod, self).__init__(*args, **kwargs)
-        self.supports_depends_on = StrictVersion(self.version) >= StrictVersion(self.REQ_VERSION_DEPENDS_ON)
+        version = StrictVersion(self.version)
+
+        self.supports_depends_on = version >= self.REQ_VERSION_DEPENDS_ON
+        # See https://lmod.readthedocs.io/en/latest/125_personal_spider_cache.html
+        if version >= '8.7.12':
+            self.USER_CACHE_DIR = os.path.join(os.path.expanduser('~'), '.cache', 'lmod')
+        else:
+            self.USER_CACHE_DIR = os.path.join(os.path.expanduser('~'), '.lmod.d', '.cache')
 
     def check_module_function(self, *args, **kwargs):
         """Check whether selected module tool matches 'module' function definition."""
@@ -1438,7 +1511,8 @@ class Lmod(ModulesTool):
                 # don't actually update local cache when testing, just return the cache contents
                 return stdout
             else:
-                cache_fp = os.path.join(self.USER_CACHE_DIR, 'moduleT.lua')
+                suffix = build_option('module_cache_suffix') or ''
+                cache_fp = os.path.join(self.USER_CACHE_DIR, 'moduleT%s.lua' % suffix)
                 self.log.debug("Updating Lmod spider cache %s with output from '%s'" % (cache_fp, ' '.join(cmd)))
                 cache_dir = os.path.dirname(cache_fp)
                 if not os.path.exists(cache_dir):
