@@ -33,7 +33,9 @@ Authors:
 """
 # these are not used here, but imported from here in other places
 import ConfigParser as configparser  # noqa
+import imp
 import json
+import os
 import subprocess
 import time
 import urllib2 as std_urllib  # noqa
@@ -45,6 +47,9 @@ from StringIO import StringIO  # noqa
 from urllib import urlencode  # noqa
 from urllib2 import HTTPError, HTTPSHandler, Request, URLError, build_opener, urlopen  # noqa
 
+# Use the safe version. In Python 3.2+ this is the default already
+ConfigParser = configparser.SafeConfigParser
+
 
 # reload function (built-in in Python 2)
 reload = reload
@@ -56,6 +61,11 @@ string_type = basestring
 json_loads = json.loads
 
 
+def load_source(filename, path):
+    """Load Python module"""
+    return imp.load_source(filename, path)
+
+
 def subprocess_popen_text(cmd, **kwargs):
     """Call subprocess.Popen with specified named arguments."""
     kwargs.setdefault('stderr', subprocess.PIPE)
@@ -106,3 +116,11 @@ def sort_looseversions(looseversions):
     # with Python 2, we can safely use 'sorted' on LooseVersion instances
     # (but we can't in Python 3, see https://bugs.python.org/issue14894)
     return sorted(looseversions)
+
+
+def makedirs(name, mode=0o777, exist_ok=False):
+    try:
+        os.makedirs(name, mode)
+    except OSError:
+        if not exist_ok or not os.path.isdir(name):
+            raise
