@@ -40,12 +40,15 @@ import urllib.request as std_urllib  # noqa
 from collections import OrderedDict  # noqa
 from collections.abc import Mapping  # noqa
 from functools import cmp_to_key
+from importlib.util import spec_from_file_location, module_from_spec
 from html.parser import HTMLParser  # noqa
 from itertools import zip_longest
 from io import StringIO  # noqa
+from os import makedirs  # noqa
 from string import ascii_letters, ascii_lowercase  # noqa
 from urllib.request import HTTPError, HTTPSHandler, Request, URLError, build_opener, urlopen  # noqa
 from urllib.parse import urlencode  # noqa
+from configparser import ConfigParser  # noqa
 
 # reload function (no longer a built-in in Python 3)
 # importlib only works with Python 3.4 & newer
@@ -62,6 +65,14 @@ except ImportError:
 string_type = str
 
 
+def load_source(filename, path):
+    """Load file as Python module"""
+    spec = spec_from_file_location(filename, path)
+    module = module_from_spec(spec)
+    spec.loader.exec_module(module)
+    return module
+
+
 def json_loads(body):
     """Wrapper for json.loads that takes into account that Python versions older than 3.6 require a string value."""
 
