@@ -1,5 +1,5 @@
 # #
-# Copyright 2009-2022 Ghent University
+# Copyright 2009-2023 Ghent University
 #
 # This file is part of EasyBuild,
 # originally created by the HPC team of Ghent University (http://ugent.be/hpc/en),
@@ -27,14 +27,16 @@ Repository tools
 
 Svn repository
 
-:author: Stijn De Weirdt (Ghent University)
-:author: Dries Verdegem (Ghent University)
-:author: Kenneth Hoste (Ghent University)
-:author: Pieter De Baets (Ghent University)
-:author: Jens Timmerman (Ghent University)
-:author: Toon Willems (Ghent University)
-:author: Ward Poelmans (Ghent University)
-:author: Fotis Georgatos (Uni.Lu, NTUA)
+Authors:
+
+* Stijn De Weirdt (Ghent University)
+* Dries Verdegem (Ghent University)
+* Kenneth Hoste (Ghent University)
+* Pieter De Baets (Ghent University)
+* Jens Timmerman (Ghent University)
+* Toon Willems (Ghent University)
+* Ward Poelmans (Ghent University)
+* Fotis Georgatos (Uni.Lu, NTUA)
 """
 import getpass
 import os
@@ -154,7 +156,7 @@ class SvnRepository(FileRepository):
         :param name: software name
         :param version: software install version, incl. toolchain & versionsuffix
         :param stats: build stats, to add to archived easyconfig
-        :param previous: list of previous build stats
+        :param previous_stats: list of previous build stats
         :return: location of archived easyconfig
         """
         path = super(SvnRepository, self).add_easyconfig(cfg, name, version, stats, previous_stats)
