@@ -41,6 +41,7 @@ import re
 import struct
 import sys
 import termios
+import warnings
 from ctypes.util import find_library
 from socket import gethostname
 from easybuild.tools.py2vs3 import subprocess_popen_text
@@ -273,7 +274,7 @@ def get_avail_core_count():
         core_cnt = int(sum(sched_getaffinity()))
     else:
         # BSD-type systems
-        out, _ = run_cmd('sysctl -n hw.ncpu', force_in_dry_run=True, trace=False, stream_output=False)
+        out, _ = run_cmd('sysctl -n hw.ncpu', force_in_dry_run=True, trace=False, stream_output=False, with_hooks=False)
         try:
             if int(out) > 0:
                 core_cnt = int(out)
@@ -310,7 +311,7 @@ def get_total_memory():
     elif os_type == DARWIN:
         cmd = "sysctl -n hw.memsize"
         _log.debug("Trying to determine total memory size on Darwin via cmd '%s'", cmd)
-        out, ec = run_cmd(cmd, force_in_dry_run=True, trace=False, stream_output=False)
+        out, ec = run_cmd(cmd, force_in_dry_run=True, trace=False, stream_output=False, with_hooks=False)
         if ec == 0:
             memtotal = int(out.strip()) // (1024**2)
 
@@ -392,14 +393,15 @@ def get_cpu_vendor():
 
     elif os_type == DARWIN:
         cmd = "sysctl -n machdep.cpu.vendor"
-        out, ec = run_cmd(cmd, force_in_dry_run=True, trace=False, stream_output=False, log_ok=False)
+        out, ec = run_cmd(cmd, force_in_dry_run=True, trace=False, stream_output=False, log_ok=False, with_hooks=False)
         out = out.strip()
         if ec == 0 and out in VENDOR_IDS:
             vendor = VENDOR_IDS[out]
             _log.debug("Determined CPU vendor on DARWIN as being '%s' via cmd '%s" % (vendor, cmd))
         else:
             cmd = "sysctl -n machdep.cpu.brand_string"
-            out, ec = run_cmd(cmd, force_in_dry_run=True, trace=False, stream_output=False, log_ok=False)
+            out, ec = run_cmd(cmd, force_in_dry_run=True, trace=False, stream_output=False, log_ok=False,
+                              with_hooks=False)
             out = out.strip().split(' ')[0]
             if ec == 0 and out in CPU_VENDORS:
                 vendor = out
@@ -502,7 +504,7 @@ def get_cpu_model():
 
     elif os_type == DARWIN:
         cmd = "sysctl -n machdep.cpu.brand_string"
-        out, ec = run_cmd(cmd, force_in_dry_run=True, trace=False, stream_output=False)
+        out, ec = run_cmd(cmd, force_in_dry_run=True, trace=False, stream_output=False, with_hooks=False)
         if ec == 0:
             model = out.strip()
             _log.debug("Determined CPU model on Darwin using cmd '%s': %s" % (cmd, model))
@@ -547,7 +549,7 @@ def get_cpu_speed():
     elif os_type == DARWIN:
         cmd = "sysctl -n hw.cpufrequency_max"
         _log.debug("Trying to determine CPU frequency on Darwin via cmd '%s'" % cmd)
-        out, ec = run_cmd(cmd, force_in_dry_run=True, trace=False, stream_output=False)
+        out, ec = run_cmd(cmd, force_in_dry_run=True, trace=False, stream_output=False, with_hooks=False)
         out = out.strip()
         cpu_freq = None
         if ec == 0 and out:
@@ -595,7 +597,8 @@ def get_cpu_features():
         for feature_set in ['extfeatures', 'features', 'leaf7_features']:
             cmd = "sysctl -n machdep.cpu.%s" % feature_set
             _log.debug("Trying to determine CPU features on Darwin via cmd '%s'", cmd)
-            out, ec = run_cmd(cmd, force_in_dry_run=True, trace=False, stream_output=False, log_ok=False)
+            out, ec = run_cmd(cmd, force_in_dry_run=True, trace=False, stream_output=False, log_ok=False,
+                              with_hooks=False)
             if ec == 0:
                 cpu_feat.extend(out.strip().lower().split())
 
@@ -623,7 +626,7 @@ def get_gpu_info():
             cmd = "nvidia-smi --query-gpu=gpu_name,driver_version --format=csv,noheader"
             _log.debug("Trying to determine NVIDIA GPU info on Linux via cmd '%s'", cmd)
             out, ec = run_cmd(cmd, simple=False, log_ok=False, log_all=False,
-                              force_in_dry_run=True, trace=False, stream_output=False)
+                              force_in_dry_run=True, trace=False, stream_output=False, with_hooks=False)
             if ec == 0:
                 for line in out.strip().split('\n'):
                     nvidia_gpu_info = gpu_info.setdefault('NVIDIA', {})
@@ -642,14 +645,14 @@ def get_gpu_info():
             cmd = "rocm-smi --showdriverversion --csv"
             _log.debug("Trying to determine AMD GPU driver on Linux via cmd '%s'", cmd)
             out, ec = run_cmd(cmd, simple=False, log_ok=False, log_all=False,
-                              force_in_dry_run=True, trace=False, stream_output=False)
+                              force_in_dry_run=True, trace=False, stream_output=False, with_hooks=False)
             if ec == 0:
                 amd_driver = out.strip().split('\n')[1].split(',')[1]
 
             cmd = "rocm-smi --showproductname --csv"
             _log.debug("Trying to determine AMD GPU info on Linux via cmd '%s'", cmd)
             out, ec = run_cmd(cmd, simple=False, log_ok=False, log_all=False,
-                              force_in_dry_run=True, trace=False, stream_output=False)
+                              force_in_dry_run=True, trace=False, stream_output=False, with_hooks=False)
             if ec == 0:
                 for line in out.strip().split('\n')[1:]:
                     amd_card_series = line.split(',')[1]
@@ -734,7 +737,10 @@ def get_os_name():
     if hasattr(platform, 'linux_distribution'):
         # platform.linux_distribution is more useful, but only available since Python 2.6
         # this allows to differentiate between Fedora, CentOS, RHEL and Scientific Linux (Rocks is just CentOS)
-        os_name = platform.linux_distribution()[0].strip()
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore", category=PendingDeprecationWarning)
+            warnings.simplefilter("ignore", category=DeprecationWarning)
+            os_name = platform.linux_distribution()[0].strip()
 
     # take into account that on some OSs, platform.distribution returns an empty string as OS name,
     # for example on OpenSUSE Leap 15.2
@@ -771,7 +777,10 @@ def get_os_version():
 
     # platform.dist was removed in Python 3.8
     if hasattr(platform, 'dist'):
-        os_version = platform.dist()[1]
+        with warnings.catch_warnings():
+            warnings.simplefilter("ignore", category=PendingDeprecationWarning)
+            warnings.simplefilter("ignore", category=DeprecationWarning)
+            os_version = platform.dist()[1]
 
     # take into account that on some OSs, platform.dist returns an empty string as OS version,
     # for example on OpenSUSE Leap 15.2
@@ -873,9 +882,14 @@ def check_os_dependency(dep):
 
         # try locate if it's available
         if not found and which('locate'):
-            cmd = 'locate --regexp "/%s$"' % dep
-            found = run_cmd(cmd, simple=True, log_all=False, log_ok=False, force_in_dry_run=True, trace=False,
-                            stream_output=False)
+            cmd = 'locate -c --regexp "/%s$"' % dep
+            out, ec = run_cmd(cmd, simple=False, log_all=False, log_ok=False, force_in_dry_run=True, trace=False,
+                              stream_output=False)
+            try:
+                found = (ec == 0 and int(out.strip()) > 0)
+            except ValueError:
+                # Returned something else than an int -> Error
+                found = False
 
     return found
 
@@ -886,7 +900,7 @@ def get_tool_version(tool, version_option='--version', ignore_ec=False):
     Output is returned as a single-line string (newlines are replaced by '; ').
     """
     out, ec = run_cmd(' '.join([tool, version_option]), simple=False, log_ok=False, force_in_dry_run=True,
-                      trace=False, stream_output=False)
+                      trace=False, stream_output=False, with_hooks=False)
     if not ignore_ec and ec:
         _log.warning("Failed to determine version of %s using '%s %s': %s" % (tool, tool, version_option, out))
         return UNKNOWN
@@ -931,7 +945,9 @@ def get_glibc_version():
 
     if os_type == LINUX:
         glibc_ver_str = get_tool_version('ldd')
-        glibc_ver_regex = re.compile(r"^ldd \([^)]*\) (\d[\d.]*).*$")
+        # note: get_tool_version replaces newlines with ';',
+        # hence the use of ';' below after the expected glibc version
+        glibc_ver_regex = re.compile(r"^ldd \(.+\) (\d[\d.]+);")
         res = glibc_ver_regex.search(glibc_ver_str)
 
         if res is not None:
@@ -1196,7 +1212,7 @@ def det_parallelism(par=None, maxpar=None):
             raise EasyBuildError("Specified level of parallelism '%s' is not an integer value: %s", par, err)
 
     if maxpar is not None and maxpar < par:
-        _log.info("Limiting parallellism from %s to %s", par, maxpar)
+        _log.info("Limiting parallelism from %s to %s", par, maxpar)
         par = maxpar
 
     return par
@@ -1245,6 +1261,46 @@ def check_python_version():
     return (python_maj_ver, python_min_ver)
 
 
+def pick_system_specific_value(description, options_or_value, allow_none=False):
+    """Pick an entry for the current system when the input has multiple options
+
+    :param description: Descriptive string about the value to be retrieved. Used for logging.
+    :param options_or_value: Either a dictionary with options to choose from or a value of any other type
+    :param allow_none: When True and no matching arch key was found, return None instead of an error
+
+    :return options_or_value when it is not a dictionary or the matching entry (if existing)
+    """
+    result = options_or_value
+    if isinstance(options_or_value, dict):
+        if not options_or_value:
+            raise EasyBuildError("Found empty dict as %s!", description)
+        other_keys = [x for x in options_or_value.keys() if not x.startswith(ARCH_KEY_PREFIX)]
+        if other_keys:
+            other_keys = ','.join(sorted(other_keys))
+            raise EasyBuildError("Unexpected keys in %s: %s (only '%s' keys are supported)",
+                                 description, other_keys, ARCH_KEY_PREFIX)
+        host_arch_key = ARCH_KEY_PREFIX + get_cpu_architecture()
+        star_arch_key = ARCH_KEY_PREFIX + '*'
+        # check for specific 'arch=' key first
+        try:
+            result = options_or_value[host_arch_key]
+            _log.info("Selected %s from %s for %s (using key %s)",
+                      result, options_or_value, description, host_arch_key)
+        except KeyError:
+            # fall back to 'arch=*'
+            try:
+                result = options_or_value[star_arch_key]
+                _log.info("Selected %s from %s for %s (using fallback key %s)",
+                          result, options_or_value, description, star_arch_key)
+            except KeyError:
+                if allow_none:
+                    result = None
+                else:
+                    raise EasyBuildError("No matches for %s in %s (looking for %s)",
+                                         description, options_or_value, host_arch_key)
+    return result
+
+
 def pick_dep_version(dep_version):
     """
     Pick the correct dependency version to use for this system.
@@ -1252,41 +1308,16 @@ def pick_dep_version(dep_version):
     * a string value (or None)
     * a dict with options to choose from
 
-    Return value is the version to use.
+    Return value is the version to use or False to skip this dependency.
     """
-    if isinstance(dep_version, string_type):
-        _log.debug("Version is already a string ('%s'), OK", dep_version)
-        result = dep_version
-
-    elif dep_version is None:
+    if dep_version is None:
         _log.debug("Version is None, OK")
         result = None
-
-    elif isinstance(dep_version, dict):
-        arch_keys = [x for x in dep_version.keys() if x.startswith(ARCH_KEY_PREFIX)]
-        other_keys = [x for x in dep_version.keys() if x not in arch_keys]
-        if other_keys:
-            other_keys = ','.join(sorted(other_keys))
-            raise EasyBuildError("Unexpected keys in version: %s (only 'arch=' keys are supported)", other_keys)
-        if arch_keys:
-            host_arch_key = ARCH_KEY_PREFIX + get_cpu_architecture()
-            star_arch_key = ARCH_KEY_PREFIX + '*'
-            # check for specific 'arch=' key first
-            if host_arch_key in dep_version:
-                result = dep_version[host_arch_key]
-                _log.info("Version selected from %s using key %s: %s", dep_version, host_arch_key, result)
-            # fall back to 'arch=*'
-            elif star_arch_key in dep_version:
-                result = dep_version[star_arch_key]
-                _log.info("Version selected for %s using fallback key %s: %s", dep_version, star_arch_key, result)
-            else:
-                raise EasyBuildError("No matches for version in %s (looking for %s)", dep_version, host_arch_key)
-        else:
-            raise EasyBuildError("Found empty dict as version!")
-
     else:
-        typ = type(dep_version)
-        raise EasyBuildError("Unknown value type for version: %s (%s), should be string value", typ, dep_version)
+        result = pick_system_specific_value("version", dep_version)
+        if not isinstance(result, string_type) and result is not False:
+            typ = type(dep_version)
+            raise EasyBuildError("Unknown value type for version: %s (%s), should be string value", typ, dep_version)
 
     return result
 
