@@ -51,7 +51,7 @@ from easybuild.tools.systemtools import det_parallelism, get_avail_core_count, g
 from easybuild.tools.systemtools import get_cpu_family, get_cpu_features, get_cpu_model, get_cpu_speed, get_cpu_vendor
 from easybuild.tools.systemtools import get_gcc_version, get_glibc_version, get_os_type, get_os_name, get_os_version
 from easybuild.tools.systemtools import get_platform_name, get_shared_lib_ext, get_system_info, get_total_memory
-from easybuild.tools.systemtools import find_library_path, locate_solib, pick_dep_version
+from easybuild.tools.systemtools import find_library_path, locate_solib, pick_dep_version, pick_system_specific_value
 
 
 PROC_CPUINFO_TXT = None
@@ -325,7 +325,7 @@ def mocked_run_cmd(cmd, **kwargs):
     """Mocked version of run_cmd, with specified output for known commands."""
     known_cmds = {
         "gcc --version": "gcc (GCC) 5.1.1 20150618 (Red Hat 5.1.1-4)",
-        "ldd --version": "ldd (GNU libc) 2.12",
+        "ldd --version": "ldd (GNU libc) 2.12; ",
         "sysctl -n hw.cpufrequency_max": "2400000000",
         "sysctl -n hw.ncpu": '10',
         "sysctl -n hw.memsize": '8589934592',
@@ -401,7 +401,7 @@ class SystemToolsTest(EnhancedTestCase):
     def test_avail_core_count_native(self):
         """Test getting core count."""
         core_count = get_avail_core_count()
-        self.assertTrue(isinstance(core_count, int), "core_count has type int: %s, %s" % (core_count, type(core_count)))
+        self.assertIsInstance(core_count, int)
         self.assertTrue(core_count > 0, "core_count %d > 0" % core_count)
 
     def test_avail_core_count_linux(self):
@@ -422,7 +422,7 @@ class SystemToolsTest(EnhancedTestCase):
     def test_cpu_model_native(self):
         """Test getting CPU model."""
         cpu_model = get_cpu_model()
-        self.assertTrue(isinstance(cpu_model, string_type))
+        self.assertIsInstance(cpu_model, string_type)
 
     def test_cpu_model_linux(self):
         """Test getting CPU model (mocked for Linux)."""
@@ -460,8 +460,9 @@ class SystemToolsTest(EnhancedTestCase):
     def test_cpu_speed_native(self):
         """Test getting CPU speed."""
         cpu_speed = get_cpu_speed()
-        self.assertTrue(isinstance(cpu_speed, float) or cpu_speed is None)
-        self.assertTrue(cpu_speed is None or cpu_speed > 0.0)
+        if cpu_speed is not None:
+            self.assertIsInstance(cpu_speed, float)
+            self.assertTrue(cpu_speed > 0.0)
 
     def test_cpu_speed_linux(self):
         """Test getting CPU speed (mocked for Linux)."""
@@ -494,7 +495,7 @@ class SystemToolsTest(EnhancedTestCase):
     def test_cpu_features_native(self):
         """Test getting CPU features."""
         cpu_feat = get_cpu_features()
-        self.assertTrue(isinstance(cpu_feat, list))
+        self.assertIsInstance(cpu_feat, list)
         self.assertTrue(len(cpu_feat) >= 0)
         self.assertTrue(all(isinstance(x, string_type) for x in cpu_feat))
 
@@ -556,7 +557,7 @@ class SystemToolsTest(EnhancedTestCase):
     def test_cpu_architecture_native(self):
         """Test getting the CPU architecture."""
         arch = get_cpu_architecture()
-        self.assertTrue(arch in CPU_ARCHITECTURES)
+        self.assertIn(arch, CPU_ARCHITECTURES)
 
     def test_cpu_architecture(self):
         """Test getting the CPU architecture (mocked)."""
@@ -580,7 +581,7 @@ class SystemToolsTest(EnhancedTestCase):
     def test_cpu_arch_name_native(self):
         """Test getting CPU arch name."""
         arch_name = get_cpu_arch_name()
-        self.assertTrue(isinstance(arch_name, string_type))
+        self.assertIsInstance(arch_name, string_type)
 
     def test_cpu_arch_name(self):
         """Test getting CPU arch name."""
@@ -601,7 +602,7 @@ class SystemToolsTest(EnhancedTestCase):
     def test_cpu_vendor_native(self):
         """Test getting CPU vendor."""
         cpu_vendor = get_cpu_vendor()
-        self.assertTrue(cpu_vendor in CPU_VENDORS)
+        self.assertIn(cpu_vendor, CPU_VENDORS)
 
     def test_cpu_vendor_linux(self):
         """Test getting CPU vendor (mocked for Linux)."""
@@ -694,12 +695,12 @@ class SystemToolsTest(EnhancedTestCase):
     def test_os_type(self):
         """Test getting OS type."""
         os_type = get_os_type()
-        self.assertTrue(os_type in [DARWIN, LINUX])
+        self.assertIn(os_type, [DARWIN, LINUX])
 
     def test_shared_lib_ext_native(self):
         """Test getting extension for shared libraries."""
         ext = get_shared_lib_ext()
-        self.assertTrue(ext in ['dylib', 'so'])
+        self.assertIn(ext, ['dylib', 'so'])
 
     def test_shared_lib_ext_linux(self):
         """Test getting extension for shared libraries (mocked for Linux)."""
@@ -714,12 +715,12 @@ class SystemToolsTest(EnhancedTestCase):
     def test_platform_name_native(self):
         """Test getting platform name."""
         platform_name_nover = get_platform_name()
-        self.assertTrue(isinstance(platform_name_nover, string_type))
+        self.assertIsInstance(platform_name_nover, string_type)
         len_nover = len(platform_name_nover.split('-'))
         self.assertTrue(len_nover >= 3)
 
         platform_name_ver = get_platform_name(withversion=True)
-        self.assertTrue(isinstance(platform_name_ver, string_type))
+        self.assertIsInstance(platform_name_ver, string_type)
         len_ver = len(platform_name_ver.split('-'))
         self.assertTrue(platform_name_ver.startswith(platform_name_ver))
         self.assertTrue(len_ver >= len_nover)
@@ -764,7 +765,8 @@ class SystemToolsTest(EnhancedTestCase):
     def test_gcc_version_native(self):
         """Test getting gcc version."""
         gcc_version = get_gcc_version()
-        self.assertTrue(isinstance(gcc_version, string_type) or gcc_version is None)
+        if gcc_version is not None:
+            self.assertIsInstance(gcc_version, string_type)
 
     def test_gcc_version_linux(self):
         """Test getting gcc version (mocked for Linux)."""
@@ -789,6 +791,13 @@ class SystemToolsTest(EnhancedTestCase):
         st.run_cmd = mocked_run_cmd
         self.assertEqual(get_glibc_version(), '2.12')
 
+    def test_glibc_version_linux_gentoo(self):
+        """Test getting glibc version (mocked for Linux)."""
+        st.get_os_type = lambda: st.LINUX
+        ldd_version_out = "ldd (Gentoo 2.37-r3 (patchset 5)) 2.37; Copyright (C) 2023 Free Software Foundation, Inc."
+        st.get_tool_version = lambda _: ldd_version_out
+        self.assertEqual(get_glibc_version(), '2.37')
+
     def test_glibc_version_linux_musl_libc(self):
         """Test getting glibc version (mocked for Linux)."""
         st.get_os_type = lambda: st.LINUX
@@ -816,19 +825,19 @@ class SystemToolsTest(EnhancedTestCase):
     def test_get_total_memory_native(self):
         """Test the function that gets the total memory."""
         memtotal = get_total_memory()
-        self.assertTrue(isinstance(memtotal, int))
+        self.assertIsInstance(memtotal, int)
 
     def test_system_info(self):
         """Test getting system info."""
         system_info = get_system_info()
-        self.assertTrue(isinstance(system_info, dict))
+        self.assertIsInstance(system_info, dict)
 
     def test_det_parallelism_native(self):
         """Test det_parallelism function (native calls)."""
         self.assertTrue(det_parallelism() > 0)
-        # specified parallellism
+        # specified parallelism
         self.assertEqual(det_parallelism(par=5), 5)
-        # max parallellism caps
+        # max parallelism caps
         self.assertEqual(det_parallelism(maxpar=1), 1)
         self.assertEqual(det_parallelism(16, 1), 1)
         self.assertEqual(det_parallelism(par=5, maxpar=2), 2)
@@ -889,7 +898,7 @@ class SystemToolsTest(EnhancedTestCase):
         self.mock_stderr(False)
         self.assertFalse(stderr)
 
-        self.assertTrue(py_maj_ver in [2, 3])
+        self.assertIn(py_maj_ver, [2, 3])
         if py_maj_ver == 2:
             self.assertTrue(py_min_ver == 7)
         else:
@@ -933,6 +942,38 @@ class SystemToolsTest(EnhancedTestCase):
         error_pattern = r"Unknown value type for version: .* \(1.23\), should be string value"
         self.assertErrorRegex(EasyBuildError, error_pattern, pick_dep_version, 1.23)
 
+    def test_pick_system_specific_value(self):
+        """Test pick_system_specific_value function."""
+
+        self.assertEqual(pick_system_specific_value('test-desc', None), None)
+        self.assertEqual(pick_system_specific_value('test-desc', '1.2.3'), '1.2.3')
+        self.assertEqual(pick_system_specific_value('test-desc', (42, 'foobar')), (42, 'foobar'))
+
+        option_dict = {
+            'arch=x86_64': '1.2.3-amd64',
+            'arch=POWER': '1.2.3-ppc64le',
+            'arch=*': '1.2.3-other',
+        }
+
+        st.get_cpu_architecture = lambda: X86_64
+        self.assertEqual(pick_system_specific_value('test-desc', option_dict), '1.2.3-amd64')
+
+        st.get_cpu_architecture = lambda: POWER
+        self.assertEqual(pick_system_specific_value('test-desc', option_dict), '1.2.3-ppc64le')
+
+        st.get_cpu_architecture = lambda: "NON_EXISTING_ARCH"
+        self.assertEqual(pick_system_specific_value('test-desc', option_dict), '1.2.3-other')
+
+        error_pattern = "Found empty dict as test-desc"
+        self.assertErrorRegex(EasyBuildError, error_pattern, pick_system_specific_value, 'test-desc', {})
+
+        error_pattern = r"Unexpected keys in test-desc: foo \(only 'arch=' keys are supported\)"
+        self.assertErrorRegex(EasyBuildError, error_pattern, pick_system_specific_value, 'test-desc',
+                              {'foo': '1'})
+        error_pattern = r"Unexpected keys in test-desc: foo \(only 'arch=' keys are supported\)"
+        self.assertErrorRegex(EasyBuildError, error_pattern, pick_system_specific_value, 'test-desc',
+                              {'foo': '1', 'arch=POWER': '2'})
+
     def test_check_os_dependency(self):
         """Test check_os_dependency."""
 
@@ -1076,7 +1117,7 @@ class SystemToolsTest(EnhancedTestCase):
             if libc_obj:
                 libc_path = locate_solib(libc_obj)
                 self.assertEqual(os.path.basename(libc_path), libname)
-                self.assertTrue(os.path.exists(libc_path), "%s should exist" % libname)
+                self.assertExists(libc_path)
 
     def test_find_library_path(self):
         """Test find_library_path function (Linux and Darwin only)."""
@@ -1091,7 +1132,8 @@ class SystemToolsTest(EnhancedTestCase):
         if libname:
             lib_path = find_library_path(libname)
             self.assertEqual(os.path.basename(lib_path), libname)
-            self.assertTrue(os.path.exists(lib_path) or os_type == DARWIN, "%s should exist" % libname)
+            if os_type != DARWIN:
+                self.assertExists(lib_path)
 
 
 def suite():
